# English introduction
The same time compression and decompression genius, simultaneously decompresses all kinds of compressed packages in the same directory

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

# 中文介绍
同夹压缩速解精灵，同时解压同目录下所有任意种类压缩包

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

# 用法
> pip install unzip
> py -m unzip.py
- - - - - - - - - - - - - - - - - - - - - - - - - - - -
# bug反馈
### 如您在使用中发现任何问题，请访问作者[GitHub](https://github.com/CHUA-X/Unzip/issues "作者的GitHub")留言反馈，谢谢！